/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (mini_window_data)
#endif
#ifdef __GNUC__
static const guint8 mini_window_data[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 mini_window_data[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1024) */
  "\0\0\4\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (64) */
  "\0\0\0@"
  /* width (16) */
  "\0\0\0\20"
  /* height (16) */
  "\0\0\0\20"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207"
  "\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J"
  "\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377"
  "\40J\207\377\40J\207\377\0\0\0\0\0\0\0\0\40J\207\377r\237\317\377r\237"
  "\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317"
  "\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377"
  "\40J\207\377\0\0\0\0\0\0\0\0\40J\207\377r\237\317\3774e\244\3774e\244"
  "\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244"
  "\3774e\244\377r\237\317\377\40J\207\377\0\0\0\0\0\0\0\0\210\212\205\377"
  "\377\377\377\377\327\333\324\377\330\333\324\377\331\334\325\377\330"
  "\333\324\377\331\334\325\377\331\335\326\377\332\335\327\377\334\336"
  "\330\377\334\337\331\377\335\337\332\377\377\377\377\377\210\212\205"
  "\377\0\0\0\0\0\0\0\0\210\212\205\377\377\377\377\377\331\334\326\377"
  "\331\335\326\377\332\335\327\377\331\335\326\377\332\335\327\377\333"
  "\336\330\377\335\337\331\377\335\340\332\377\335\340\332\377\337\341"
  "\334\377\377\377\377\377\210\212\205\377\0\0\0\0\0\0\0\0\210\212\205"
  "\377\377\377\377\377\333\336\327\377\334\336\330\377\334\336\331\377"
  "\334\336\330\377\334\336\331\377\334\337\331\377\335\340\333\377\337"
  "\341\333\377\340\342\334\377\340\342\335\377\377\377\377\377\210\212"
  "\205\377\0\0\0\0\0\0\0\0\210\212\205\377\377\377\377\377\334\337\330"
  "\377\335\337\331\377\336\340\332\377\335\337\331\377\336\340\332\377"
  "\337\341\334\377\337\341\334\377\340\342\335\377\341\343\336\377\341"
  "\343\337\377\377\377\377\377\210\212\205\377\0\0\0\0\0\0\0\0\210\212"
  "\205\377\377\377\377\377\335\340\332\377\336\341\333\377\337\342\334"
  "\377\336\341\333\377\337\342\334\377\340\343\335\377\341\343\336\377"
  "\342\344\337\377\342\345\337\377\343\345\340\377\377\377\377\377\210"
  "\212\205\377\0\0\0\0\0\0\0\0\210\212\205\377\377\377\377\377\337\342"
  "\334\377\340\342\335\377\341\343\335\377\336\341\333\377\337\342\334"
  "\377\340\343\335\377\341\343\336\377\342\344\337\377\342\345\337\377"
  "\343\345\340\377\377\377\377\377\210\212\205\377\0\0\0\0\0\0\0\0\210"
  "\212\205\377\377\377\377\377\337\342\334\377\340\342\335\377\341\343"
  "\335\377\340\342\335\377\341\343\335\377\342\343\336\377\343\344\340"
  "\377\343\345\340\377\344\346\342\377\345\346\342\377\377\377\377\377"
  "\210\212\205\377\0\0\0\0\0\0\0\0\210\212\205\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\210\212\205\377\0\0\0\0\0\0\0\0"
  "\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210"
  "\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212"
  "\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205"
  "\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (window_data)
#endif
#ifdef __GNUC__
static const guint8 window_data[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 window_data[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (4096) */
  "\0\0\20\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (128) */
  "\0\0\0\200"
  /* width (32) */
  "\0\0\0\40"
  /* height (32) */
  "\0\0\0\40"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\40J\207\377\40J\207\377\40J\207\377\40J\207\377"
  "\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207"
  "\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J"
  "\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377"
  "\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207"
  "\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\377\40J\207"
  "\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J"
  "\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377"
  "\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207"
  "\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J\207\377\40J"
  "\207\377\40J\207\377\40J\207\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\40J\207\377\40J\207\377r\237\317\377r\237\317\377r\237\317\377"
  "r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237"
  "\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317"
  "\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377"
  "r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377\40"
  "J\207\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\377\40"
  "J\207\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317"
  "\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377"
  "r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237"
  "\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317\377r\237\317"
  "\377r\237\317\377r\237\317\377r\237\317\377\40J\207\377\40J\207\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\40J\207\377\40J\207\377r\237\317\377r"
  "\237\317\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244"
  "\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244"
  "\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244"
  "\377r\237\317\377r\237\317\377\40J\207\377\40J\207\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\40J\207\377\40J\207\377r\237\317\377r\237\317\377"
  "4e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\377"
  "4e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\377"
  "4e\244\3774e\244\3774e\244\3774e\244\3774e\244\3774e\244\377r\237\317"
  "\377r\237\317\377\40J\207\377\40J\207\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\210\212\205\377\210\212\205\377\377\377\377\377\377\377\377\377"
  "\327\333\324\377\327\333\324\377\330\333\324\377\330\333\324\377\331"
  "\334\325\377\331\334\325\377\330\333\324\377\330\333\324\377\331\334"
  "\325\377\331\334\325\377\331\335\326\377\331\335\326\377\332\335\327"
  "\377\332\335\327\377\334\336\330\377\334\336\330\377\334\337\331\377"
  "\334\337\331\377\335\337\332\377\335\337\332\377\377\377\377\377\377"
  "\377\377\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\210\212\205\377\210\212\205\377\377\377\377\377\377\377\377"
  "\377\327\333\324\377\327\333\324\377\330\333\324\377\330\333\324\377"
  "\331\334\325\377\331\334\325\377\330\333\324\377\330\333\324\377\331"
  "\334\325\377\331\334\325\377\331\335\326\377\331\335\326\377\332\335"
  "\327\377\332\335\327\377\334\336\330\377\334\336\330\377\334\337\331"
  "\377\334\337\331\377\335\337\332\377\335\337\332\377\377\377\377\377"
  "\377\377\377\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\210\212\205\377\210\212\205\377\377\377\377\377\377\377"
  "\377\377\331\334\326\377\331\334\326\377\331\335\326\377\331\335\326"
  "\377\332\335\327\377\332\335\327\377\331\335\326\377\331\335\326\377"
  "\332\335\327\377\332\335\327\377\333\336\330\377\333\336\330\377\335"
  "\337\331\377\335\337\331\377\335\340\332\377\335\340\332\377\335\340"
  "\332\377\335\340\332\377\337\341\334\377\337\341\334\377\377\377\377"
  "\377\377\377\377\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205\377\377\377\377\377\377"
  "\377\377\377\331\334\326\377\331\334\326\377\331\335\326\377\331\335"
  "\326\377\332\335\327\377\332\335\327\377\331\335\326\377\331\335\326"
  "\377\332\335\327\377\332\335\327\377\333\336\330\377\333\336\330\377"
  "\335\337\331\377\335\337\331\377\335\340\332\377\335\340\332\377\335"
  "\340\332\377\335\340\332\377\337\341\334\377\337\341\334\377\377\377"
  "\377\377\377\377\377\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205\377\377\377\377\377"
  "\377\377\377\377\333\336\327\377\333\336\327\377\334\336\330\377\334"
  "\336\330\377\334\336\331\377\334\336\331\377\334\336\330\377\334\336"
  "\330\377\334\336\331\377\334\336\331\377\334\337\331\377\334\337\331"
  "\377\335\340\333\377\335\340\333\377\337\341\333\377\337\341\333\377"
  "\340\342\334\377\340\342\334\377\340\342\335\377\340\342\335\377\377"
  "\377\377\377\377\377\377\377\210\212\205\377\210\212\205\377\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205\377\377\377\377"
  "\377\377\377\377\377\333\336\327\377\333\336\327\377\334\336\330\377"
  "\334\336\330\377\334\336\331\377\334\336\331\377\334\336\330\377\334"
  "\336\330\377\334\336\331\377\334\336\331\377\334\337\331\377\334\337"
  "\331\377\335\340\333\377\335\340\333\377\337\341\333\377\337\341\333"
  "\377\340\342\334\377\340\342\334\377\340\342\335\377\340\342\335\377"
  "\377\377\377\377\377\377\377\377\210\212\205\377\210\212\205\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205\377\377\377"
  "\377\377\377\377\377\377\334\337\330\377\334\337\330\377\335\337\331"
  "\377\335\337\331\377\336\340\332\377\336\340\332\377\335\337\331\377"
  "\335\337\331\377\336\340\332\377\336\340\332\377\337\341\334\377\337"
  "\341\334\377\337\341\334\377\337\341\334\377\340\342\335\377\340\342"
  "\335\377\341\343\336\377\341\343\336\377\341\343\337\377\341\343\337"
  "\377\377\377\377\377\377\377\377\377\210\212\205\377\210\212\205\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205\377\377"
  "\377\377\377\377\377\377\377\334\337\330\377\334\337\330\377\335\337"
  "\331\377\335\337\331\377\336\340\332\377\336\340\332\377\335\337\331"
  "\377\335\337\331\377\336\340\332\377\336\340\332\377\337\341\334\377"
  "\337\341\334\377\337\341\334\377\337\341\334\377\340\342\335\377\340"
  "\342\335\377\341\343\336\377\341\343\336\377\341\343\337\377\341\343"
  "\337\377\377\377\377\377\377\377\377\377\210\212\205\377\210\212\205"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205\377"
  "\377\377\377\377\377\377\377\377\335\340\332\377\335\340\332\377\336"
  "\341\333\377\336\341\333\377\337\342\334\377\337\342\334\377\336\341"
  "\333\377\336\341\333\377\337\342\334\377\337\342\334\377\340\343\335"
  "\377\340\343\335\377\341\343\336\377\341\343\336\377\342\344\337\377"
  "\342\344\337\377\342\345\337\377\342\345\337\377\343\345\340\377\343"
  "\345\340\377\377\377\377\377\377\377\377\377\210\212\205\377\210\212"
  "\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212\205"
  "\377\377\377\377\377\377\377\377\377\335\340\332\377\335\340\332\377"
  "\336\341\333\377\336\341\333\377\337\342\334\377\337\342\334\377\336"
  "\341\333\377\336\341\333\377\337\342\334\377\337\342\334\377\340\343"
  "\335\377\340\343\335\377\341\343\336\377\341\343\336\377\342\344\337"
  "\377\342\344\337\377\342\345\337\377\342\345\337\377\343\345\340\377"
  "\343\345\340\377\377\377\377\377\377\377\377\377\210\212\205\377\210"
  "\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210\212"
  "\205\377\377\377\377\377\377\377\377\377\337\342\334\377\337\342\334"
  "\377\340\342\335\377\340\342\335\377\341\343\335\377\341\343\335\377"
  "\336\341\333\377\336\341\333\377\337\342\334\377\337\342\334\377\340"
  "\343\335\377\340\343\335\377\341\343\336\377\341\343\336\377\342\344"
  "\337\377\342\344\337\377\342\345\337\377\342\345\337\377\343\345\340"
  "\377\343\345\340\377\377\377\377\377\377\377\377\377\210\212\205\377"
  "\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377\210"
  "\212\205\377\377\377\377\377\377\377\377\377\337\342\334\377\337\342"
  "\334\377\340\342\335\377\340\342\335\377\341\343\335\377\341\343\335"
  "\377\336\341\333\377\336\341\333\377\337\342\334\377\337\342\334\377"
  "\340\343\335\377\340\343\335\377\341\343\336\377\341\343\336\377\342"
  "\344\337\377\342\344\337\377\342\345\337\377\342\345\337\377\343\345"
  "\340\377\343\345\340\377\377\377\377\377\377\377\377\377\210\212\205"
  "\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205\377"
  "\210\212\205\377\377\377\377\377\377\377\377\377\337\342\334\377\337"
  "\342\334\377\340\342\335\377\340\342\335\377\341\343\335\377\341\343"
  "\335\377\340\342\335\377\340\342\335\377\341\343\335\377\341\343\335"
  "\377\342\343\336\377\342\343\336\377\343\344\340\377\343\344\340\377"
  "\343\345\340\377\343\345\340\377\344\346\342\377\344\346\342\377\345"
  "\346\342\377\345\346\342\377\377\377\377\377\377\377\377\377\210\212"
  "\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212\205"
  "\377\210\212\205\377\377\377\377\377\377\377\377\377\337\342\334\377"
  "\337\342\334\377\340\342\335\377\340\342\335\377\341\343\335\377\341"
  "\343\335\377\340\342\335\377\340\342\335\377\341\343\335\377\341\343"
  "\335\377\342\343\336\377\342\343\336\377\343\344\340\377\343\344\340"
  "\377\343\345\340\377\343\345\340\377\344\346\342\377\344\346\342\377"
  "\345\346\342\377\345\346\342\377\377\377\377\377\377\377\377\377\210"
  "\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210\212"
  "\205\377\210\212\205\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\210"
  "\212\205\377\210\212\205\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210"
  "\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212"
  "\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205"
  "\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377"
  "\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210"
  "\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212"
  "\205\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377"
  "\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210"
  "\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212"
  "\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205"
  "\377\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377"
  "\210\212\205\377\210\212\205\377\210\212\205\377\210\212\205\377\210"
  "\212\205\377\210\212\205\377\210\212\205\377\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


